/*
  ISC License

  Copyright (c) 2016, Antonio SJ Musumeci <trapexit@spawn.link>

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#pragma once

#include "to_neg_errno.hpp"
#include "xattr.hpp"

#include <string>

#include <sys/types.h>


namespace fs
{
  static
  inline
  ssize_t
  llistxattr(const char   *path_,
             char         *list_,
             const size_t  size_)
  {
#ifdef USE_XATTR
    ssize_t rv;

    rv = ::llistxattr(path_,list_,size_);

    return ::to_neg_errno(rv);
#else
    return -ENOTSUP;
#endif
  }

  static
  inline
  ssize_t
  llistxattr(const std::string &path_,
             char              *list_,
             const size_t       size_)
  {
    return fs::llistxattr(path_.c_str(),list_,size_);
  }
}
